

export const index = 29;
let component_cache;
export const component = async () => component_cache ??= (await import('../entries/pages/(app)/workspace/functions/create/_page.svelte.js')).default;
export const imports = ["_app/immutable/nodes/29.V5pnWVxu.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/BY-rXZ0_.js"];
export const stylesheets = [];
export const fonts = [];
